@@ -1,5 +1,6 @@
 /*  wmnet -- X IP accounting monitor
- *  Copyright 1998 Jesse B. Off  <joff@iastate.edu>
+ *  Copyright 1998 Jesse B. Off
+ *  Copyright 2000 Katharine Osborne
  *
  *  $Id: wmnet.c,v 1.28 1998/10/07 03:42:28 joff Exp joff $
  *  
@@ -45,6 +46,7 @@
  *  6/18/1998  --  Slowed down the speedometer display... it was getting annoying.
  *  6/23/1998  --  Split up to wmnet.c and wmnet.h
  *  8/5/1998   --  New options --device and --driver
+ *  5/4/2000   --  Support added for OpenBSD
  */ 
 
 #include<stdlib.h>
@@ -53,7 +55,7 @@
 #include<X11/Xlib.h>
 #include<X11/Xutil.h>
 #include<X11/Xatom.h>
-#ifdef __FreeBSD__
+#if defined (__FreeBSD__) || defined (__OpenBSD__)
 # include<sys/socket.h>
 # include"getopt.h"
 #else
@@ -135,8 +137,8 @@ void setup_wmnet(int argc, char **argv) {
 #endif
 		switch(c) {
 			case 'v':
-				printf("wmnet 1.05\n"
-				       "Copyright (C) 1998 Jesse B. Off <joff@iastate.edu>\n"
+				printf("wmnet 1.06\n"
+				       "Copyright (C) 1998, 2000 Jesse B. Off, Katharine Osborne <kaos@digitalkaos.net>\n"
 				       "This program is released under the terms of the GNU Public License.\n");
 				exit(14);
 				break;
@@ -273,8 +275,8 @@ void setup_wmnet(int argc, char **argv) {
 				}
 				break;
 			default:
-				printf("wmnet-- v1.05  Jesse Off <joff@iastate.edu>\n"
-				       "        http://isufug.ee.iastate.edu/~joff/wmnet.html\n"
+				printf("wmnet-- v1.06 Katharine Osborne <kaos@digitalkaos.net>\n"
+				       "http://www.digitalkaos.net/linux/wmnet/\n"
 				       "-----------------------------------------------------\n"
 				       "  -h, --help               this help\n"
                                        "  -v, --version            display version information\n"
